@@ -24,7 +24,7 @@
  */
 /*
  * ===========================================================================
- * (c) Copyright IBM Corp. 2018, 2019 All Rights Reserved
+ * (c) Copyright IBM Corp. 2018, 2020 All Rights Reserved
  * ===========================================================================
  */
 package com.sun.crypto.provider;
@@ -160,10 +160,11 @@ abstract class NativeChaCha20Cipher extends CipherSpi {
      * Get the output size based on an input length.  In simple stream-cipher
      * mode, the output size will equal the input size.  For ChaCha20-Poly1305
      * for encryption the output size will be the sum of the input length
-     * and tag length.  For decryption, the output size will be the input
-     * length less the tag length or zero, whichever is larger.
+     * and tag length.  For decryption, the output size will be the sum of
+     * 1. The input length less the tag length or zero, whichever is larger.
+     * 2. The unprocessed input length.
      *
-     * @param inputLen the length in bytes of the input
+     * @param inputLen the length in bytes of the input.
      *
      * @return the output length in bytes.
      */
@@ -174,9 +175,12 @@ abstract class NativeChaCha20Cipher extends CipherSpi {
         if (mode == MODE_NONE) {
             outLen = inputLen;
         } else if (mode == MODE_AEAD) {
-            outLen = (direction == Cipher.ENCRYPT_MODE) ?
-                    Math.addExact(inputLen, TAG_LENGTH) :
-                    Integer.max(inputLen - TAG_LENGTH, 0);
+            if (direction == Cipher.ENCRYPT_MODE) {
+                outLen = Math.addExact(inputLen, TAG_LENGTH);
+            } else {
+                outLen = Integer.max(inputLen, TAG_LENGTH) - TAG_LENGTH;
+                outLen = Math.addExact(outLen, engine.getCipherBufferLength());
+            }
         }
 
         return outLen;
@@ -632,7 +636,12 @@ abstract class NativeChaCha20Cipher extends CipherSpi {
     protected byte[] engineUpdate(byte[] in, int inOfs, int inLen) {
         byte[] out = new byte[inLen];
         try {
-            engine.doUpdate(in, inOfs, inLen, out, 0);
+            int size = engine.doUpdate(in, inOfs, inLen, out, 0);
+            // Special case for EngineAEADDec, doUpdate only buffers the input
+            // So the output array must be empty since no encryption happened yet
+            if (size == 0) {
+                return new byte[0];
+            }
         } catch (ShortBufferException | KeyException exc) {
             throw new RuntimeException(exc);
         }
@@ -849,6 +858,15 @@ abstract class NativeChaCha20Cipher extends CipherSpi {
          */
         int doFinal(byte[] in, int inOff, int inLen, byte[] out, int outOff)
                 throws ShortBufferException, AEADBadTagException, KeyException;
+
+        /**
+        * Returns the length of the unprocessed input.
+        * Only used in EngineAEADDec since AEADDec does not process input in doUpdate().
+        * In other engines, the function should return zero.
+        *
+        * @return the number of unprocessed bytes left.
+        */
+        int getCipherBufferLength();
     }
 
     private final class EngineStreamOnly implements ChaChaEngine {
@@ -891,6 +909,11 @@ abstract class NativeChaCha20Cipher extends CipherSpi {
                 return inLen;
             }
         }
+
+        @Override
+        public int getCipherBufferLength() {
+            return 0;
+        }
     }
 
     private final class EngineAEADEnc implements ChaChaEngine {
@@ -955,6 +978,11 @@ abstract class NativeChaCha20Cipher extends CipherSpi {
             aadDone = false;
             return Math.addExact(inLen, TAG_LENGTH);
         }
+
+        @Override
+        public int getCipherBufferLength() {
+            return 0;
+        }
     }
 
     private final class EngineAEADDec implements ChaChaEngine {
@@ -1047,6 +1075,11 @@ abstract class NativeChaCha20Cipher extends CipherSpi {
 
             return ctLen;
         }
+
+        @Override
+        public int getCipherBufferLength() {
+            return cipherBuf.size();
+        }
     }
 
     public static final class ChaCha20Only extends NativeChaCha20Cipher {
