@@ -580,8 +580,9 @@ public static int identityHashCode(Object anObject) {
 @CallerSensitive
 public static void load(String pathName) {
 	SecurityManager smngr = System.getSecurityManager();
-	if (smngr != null)
+	if (smngr != null) {
 		smngr.checkLink(pathName);
+	}
 	ClassLoader.loadLibraryWithPath(pathName, ClassLoader.callerClassLoader(), null);
 }
 
@@ -595,6 +596,10 @@ public static void load(String pathName) {
  */
 @CallerSensitive
 public static void loadLibrary(String libName) {
+	SecurityManager smngr = System.getSecurityManager();
+	if (smngr != null) {
+		smngr.checkLink(libName);
+	}
 	ClassLoader.loadLibraryWithClassLoader(libName, ClassLoader.callerClassLoader());
 }
 
