@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2014, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -211,6 +211,7 @@ module java.base {
         java.management,
         jdk.internal.jvmstat,
         jdk.management.agent;
+    exports jdk.internal.platform to jdk.management;
     exports jdk.internal.ref to
         java.desktop,
         jdk.unsupported;
@@ -307,6 +308,7 @@ module java.base {
         jdk.crypto.cryptoki,
         jdk.crypto.ec,
         jdk.jartool,
+        jdk.naming.ldap,
         jdk.security.auth,
         jdk.security.jgss;
     exports sun.security.util.math to jdk.crypto.ec;
